@@ -142,6 +142,8 @@ from bitmovin_api_sdk.models.audio_volume_format import AudioVolumeFormat
 from bitmovin_api_sdk.models.audio_volume_unit import AudioVolumeUnit
 from bitmovin_api_sdk.models.auto_representation import AutoRepresentation
 from bitmovin_api_sdk.models.auto_restart_configuration import AutoRestartConfiguration
+from bitmovin_api_sdk.models.av1_per_title_configuration import Av1PerTitleConfiguration
+from bitmovin_api_sdk.models.av1_preset_configuration import Av1PresetConfiguration
 from bitmovin_api_sdk.models.av1_video_configuration import Av1VideoConfiguration
 from bitmovin_api_sdk.models.availability_start_time_mode import AvailabilityStartTimeMode
 from bitmovin_api_sdk.models.aws_account import AwsAccount
@@ -338,6 +340,7 @@ from bitmovin_api_sdk.models.encoding_statistics_vod import EncodingStatisticsVo
 from bitmovin_api_sdk.models.encoding_stats import EncodingStats
 from bitmovin_api_sdk.models.encoding_stream_input import EncodingStreamInput
 from bitmovin_api_sdk.models.encoding_stream_input_details import EncodingStreamInputDetails
+from bitmovin_api_sdk.models.encoding_template import EncodingTemplate
 from bitmovin_api_sdk.models.encoding_type import EncodingType
 from bitmovin_api_sdk.models.encryption_mode import EncryptionMode
 from bitmovin_api_sdk.models.enhanced_deinterlace_auto_enable import EnhancedDeinterlaceAutoEnable
@@ -599,6 +602,21 @@ from bitmovin_api_sdk.models.sidecar_error_mode import SidecarErrorMode
 from bitmovin_api_sdk.models.sidecar_file import SidecarFile
 from bitmovin_api_sdk.models.sidecar_file_type import SidecarFileType
 from bitmovin_api_sdk.models.signature_type import SignatureType
+from bitmovin_api_sdk.models.simple_encoding_live_cloud_region import SimpleEncodingLiveCloudRegion
+from bitmovin_api_sdk.models.simple_encoding_live_input_aspect_ratio import SimpleEncodingLiveInputAspectRatio
+from bitmovin_api_sdk.models.simple_encoding_live_job_access_key_credentials import SimpleEncodingLiveJobAccessKeyCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_azure_credentials import SimpleEncodingLiveJobAzureCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_credentials import SimpleEncodingLiveJobCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_gcs_service_account_credentials import SimpleEncodingLiveJobGcsServiceAccountCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_input import SimpleEncodingLiveJobInput
+from bitmovin_api_sdk.models.simple_encoding_live_job_input_type import SimpleEncodingLiveJobInputType
+from bitmovin_api_sdk.models.simple_encoding_live_job_request import SimpleEncodingLiveJobRequest
+from bitmovin_api_sdk.models.simple_encoding_live_job_response import SimpleEncodingLiveJobResponse
+from bitmovin_api_sdk.models.simple_encoding_live_job_s3_role_based_credentials import SimpleEncodingLiveJobS3RoleBasedCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_status import SimpleEncodingLiveJobStatus
+from bitmovin_api_sdk.models.simple_encoding_live_job_url_output import SimpleEncodingLiveJobUrlOutput
+from bitmovin_api_sdk.models.simple_encoding_live_job_username_password_credentials import SimpleEncodingLiveJobUsernamePasswordCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_max_resolution import SimpleEncodingLiveMaxResolution
 from bitmovin_api_sdk.models.simple_encoding_vod_job_access_key_credentials import SimpleEncodingVodJobAccessKeyCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_azure_credentials import SimpleEncodingVodJobAzureCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
